@@ -13,15 +13,15 @@ format_table <- function(NOAA, parm, spat, temp) {
   tb[["spatial"]] <- spat
   tb[["temporal"]] <- temp
 
-  print(tb, row.names = FALSE)
+  tb
 }
 
 format_coord <- function(NOAA, coord) {
 
   # split coords in long and lat
   coords <- strsplit(sf::st_as_text(NOAA$geometry), "[^[:alnum:]|.|-]+")
-  coords <- do.call(Map, c(f = c, coords)) |>
-    stats::setNames(c("geometry", "longitude", "latitude"))
+  coords <- Map(coords_df, coords)
+  coords <- do.call(rbind, coords)
 
   # remove old geometry
   NOAA <- as.data.frame(NOAA)
@@ -30,3 +30,12 @@ format_coord <- function(NOAA, coord) {
   # combine new
   cbind(NOAA_sc, coords)
 }
+
+coords_df <- function(x) {
+  subset_x <- x[2:length(x)]
+  data.frame(
+    geometry = x[1],
+    longitude = I(list(subset(subset_x, seq_along(subset_x) %% 2 != 0))),
+    latitude = I(list(subset(subset_x, seq_along(subset_x) %% 2 == 0)))
+  )
+}
