@@ -1,9 +1,5 @@
 test_that("parsing urls", {
 
-  # for CRAN
-  skip_if_offline()
-  skip_on_cran()
-
   expect_equal(
     url_parser("oxygen", 1, "annual")$external,
     "https://data.nodc.noaa.gov/thredds/dodsC/ncei/woa/oxygen/all/1.00/woa18_all_o00_01.nc"
@@ -28,7 +24,8 @@ test_that("files can be loaded from NOAA", {
   skip_if_offline()
   skip_on_cran()
 
-  expect_snapshot(
-    get_NOAA("temperature", 1, "annual")
-  )
+  try(NOAA <- get_NOAA("temperature", 1, "annual"), silent = TRUE)
+  # skip if not obtained
+  skip_if_not(exists("NOAA"))
+  expect_snapshot(NOAA)
 })
